@@ -465,7 +465,7 @@ class HardwareIOTypeForm(forms.Form):
 
 
 
-from django.forms.models import inlineformset_factory,BaseForm,form_factory
+from django.forms.models import inlineformset_factory,BaseForm
 from data.models.models import HardwareStats,DataTransformer,DataTransformerConstants,HardwareDataTransformer,HardwareStatsDataTransformer
 
 DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer, extra=1)
